@@ -7,7 +7,7 @@ package Dist::Zilla::PluginBundle::Author::KENTNL;
 
 # ABSTRACT: BeLike::KENTNL when you build your distributions.
 
-our $VERSION = '2.024002';
+our $VERSION = '2.025000';
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
@@ -273,11 +273,14 @@ has 'bumpversions' => (
 
 
 
+
+
+
 has copyfiles => (
-  is      => ro  =>,
-  isa     => 'ArrayRef[ Str ]',
-  lazy    => 1,
-  default => sub { [] },
+  is   => ro =>,
+  isa  => 'ArrayRef[ Str ]',
+  lazy => 1,
+  default => sub { [ 'LICENSE', 'Makefile.PL' ] },
 );
 
 
@@ -392,11 +395,22 @@ sub _configure_basic_metadata {
   return;
 }
 
+sub _none_match {
+  my ( $item, @list ) = @_;
+  for my $list_item (@list) {
+    return if $item eq $list_item;
+  }
+  return 1;
+}
+
 sub _configure_basic_files {
   my ($self)         = @_;
-  my (@ignore_files) = qw( README README.mkdn README.pod );
-
-  push @ignore_files, @{ $self->copyfiles };
+  my (@ignore_files) = qw( README README.mkdn README.pod CONTRIBUTING.mkdn );
+  my (@copyfiles)    = ();
+  if ( _none_match 'none', @{ $self->copyfiles } ) {
+    push @copyfiles, @{ $self->copyfiles };
+  }
+  push @ignore_files, @copyfiles;
 
   $self->add_plugin(
     'Git::GatherDir' => {
@@ -410,9 +424,16 @@ sub _configure_basic_files {
   $self->add_plugin( 'MetaYAML::Minimal'        => {} );
   $self->add_plugin( 'Manifest'                 => {} );
   $self->add_plugin( 'Author::KENTNL::TravisCI' => { ':version' => '0.001002' } );
+  $self->add_plugin(
+    'Author::KENTNL::CONTRIBUTING' => {
+      ':version' => '0.001002',
+      document_version => '0.1',
+      format           => 'mkdn',
+    },
+  );
 
-  if ( @{ $self->copyfiles } ) {
-    $self->add_named_plugin( 'CopyXBuild' => 'CopyFilesFromBuild', { copy => [ @{ $self->copyfiles } ] } );
+  if (@copyfiles) {
+    $self->add_named_plugin( 'CopyXBuild' => 'CopyFilesFromBuild', { copy => [@copyfiles] } );
   }
 
   return;
@@ -543,6 +564,7 @@ sub _configure_toolkit_prereqs {
       modules       => [@bundles],
     },
   );
+  $self->add_plugin( 'RemovePrereqs::Provided' => {} );
   return;
 }
 
@@ -630,7 +652,14 @@ sub configure {
   $self->add_named_plugin( 'commit_dirty_files' => 'Git::Commit' => {} );
   $self->add_named_plugin( 'tag_master', => 'Git::Tag' => { tag_format => '%v-source' } );
   $self->add_plugin(
-    'Git::NextRelease' => { ':version' => '0.004000', time_zone => 'UTC', format => q[%v %{yyyy-MM-dd'T'HH:mm:ss}dZ %h] } );
+    'Git::NextRelease' => {
+      ':version'     => '0.004000',
+      time_zone      => 'UTC',
+      format         => q[%v %{yyyy-MM-dd'T'HH:mm:ss}dZ %h],
+      default_branch => 'master',
+    },
+  );
+
   if ( $self->bumpversions ) {
     $self->add_plugin( 'BumpVersionAfterRelease' => {} );
   }
@@ -708,7 +737,7 @@ Dist::Zilla::PluginBundle::Author::KENTNL - BeLike::KENTNL when you build your d
 
 =head1 VERSION
 
-version 2.024002
+version 2.025000
 
 =head1 SYNOPSIS
 
@@ -931,11 +960,14 @@ C<[Git::NextVersion::Sanitized]>
 
 An array of files generated by C<Dist::Zilla> build to copy from the built dist back to the source dist
 
+If not specified, the default contents are as follows:
+
   copyfiles = LICENSE
-  ; Warning: These two are presently bad ideas
-  ; and will ultimately give version mismatches
   copyfiles = Makefile.PL
-  copyfiles = META.json
+
+These defaults can be wiped with:
+
+  copyfiles = none
 
 =head2 C<srcreadme>
 
